@@ -455,7 +455,9 @@ class A(unittest.TestCase):
 
 
     def test_MalformedModuleByName(self):
-        "We don't crash attempting to load a module with a SyntaxError"
+        """
+        Don't crash discovering tests in package with module with SyntaxError.
+        """
         fh = open(os.path.join(self.tmpdir, '__init__.py'), 'w')
         fh.write('\n')
         fh.close()
@@ -466,7 +468,10 @@ class A(unittest.TestCase):
         fh.close()
         # Load the tests
         tests = loader.loadTargets(malformed_module)
-        self.assertEqual(tests, None)
+        self.assertEqual(tests.countTestCases(), 1)
+        test = tests._tests[0]._tests[0]
+        test_method = getattr(test, test._testMethodName)
+        self.assertRaises(ImportError, test_method)
 
 
     def test_partiallyGoodName(self):
@@ -527,11 +532,9 @@ class A(unittest.TestCase):
     def test_duplicate_targets(self):
         "Specifying duplicate targets does not cause duplicate loading."
         sub_tmpdir = tempfile.mkdtemp(dir=self.tmpdir)
-        # pkg/__init__.py
         fh = open(os.path.join(sub_tmpdir, '__init__.py'), 'w')
         fh.write('\n')
         fh.close()
-        # pkg/test/test_dupe_target.py
         fh = open(os.path.join(sub_tmpdir, 'test_dupe_target.py'), 'w')
         fh.write("""
 import unittest
@@ -539,10 +542,26 @@ class A(unittest.TestCase):
     def testPasses(self):
         pass""")
         fh.close()
-        # Load the tests
+
         os.chdir(self.tmpdir)
         pkg = os.path.basename(sub_tmpdir)
         tests = loader.loadTargets([pkg + '.' + 'test_dupe_target',
                                  pkg + '.' + 'test_dupe_target',
                                  pkg + '.' + 'test_dupe_target'])
         self.assertEqual(tests.countTestCases(), 1)
+
+
+    def test_explicit_filename_error(self):
+        """
+        Loading a module by name with a syntax error produces a failure, not a
+        silent absence of its tests.
+        """
+        sub_tmpdir = tempfile.mkdtemp(dir=self.tmpdir)
+        fh = open(os.path.join(sub_tmpdir, 'mod_with_import_error.py'), 'w')
+        fh.write('this is a syntax error')
+        fh.close()
+
+        os.chdir(sub_tmpdir)
+        tests = loader.loadTargets('mod_with_import_error.py')
+        self.assertEqual(tests.countTestCases(), 1)
+
